@@ -1,7 +1,7 @@
 /* amitk_filter.c
  *
  * Part of amide - Amide's a Medical Image Dataset Examiner
- * Copyright (C) 2000-2012 Andy Loening
+ * Copyright (C) 2000-2014 Andy Loening
  *
  * Author: Andy Loening <loening@alum.mit.edu>
  */
@@ -31,10 +31,8 @@
 #include <gsl/gsl_complex_math.h>
 #endif
 
-inline amide_real_t gaussian(amide_real_t x, amide_real_t sigma) {
-  
+static inline amide_real_t gaussian(amide_real_t x, amide_real_t sigma) {
   return exp(-(x*x)/(2.0*sigma*sigma))/(sigma*sqrt(2*M_PI));
-
 }
 
 /* gaussian kernel is returned in a packad array (alternating real and imaginary parts 
